@@ -6,6 +6,10 @@ use core::fmt;
 #[cfg(feature = "alloc")]
 pub(crate) const DER_ENCODING_MSG: &str = "DER encoding error";
 
+/// Message to display when an `expect`-ed PEM encoding error occurs
+#[cfg(feature = "pem")]
+pub(crate) const PEM_ENCODING_MSG: &str = "PEM encoding error";
+
 /// Result type
 pub type Result<T> = core::result::Result<T, Error>;
 
@@ -49,6 +53,7 @@ pub enum Error {
     PermissionDenied,
 
     /// PEM encoding errors.
+    // TODO(tarcieri): propagate `pem_rfc7468::Error`
     #[cfg(feature = "pem")]
     Pem,
 }
@@ -87,6 +92,14 @@ impl From<der::ErrorKind> for Error {
     }
 }
 
+#[cfg(feature = "pem")]
+impl From<pem_rfc7468::Error> for Error {
+    fn from(_: pem_rfc7468::Error) -> Error {
+        // TODO(tarcieri): propagate `pem_rfc7468::Error`
+        Error::Pem
+    }
+}
+
 #[cfg(feature = "std")]
 impl From<std::io::Error> for Error {
     fn from(err: std::io::Error) -> Error {
